@@ -1,7 +1,22 @@
+# Copyright The Lightning AI team.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import pathlib
 import re
 import shutil
 import subprocess
+import sys
 import tarfile
 import urllib.request
 from pathlib import Path
@@ -107,7 +122,7 @@ def download_frontend(destination: Path) -> None:
         response = urllib.request.urlopen(url)
         file = tarfile.open(fileobj=response, mode="r|gz")
         file.extractall(path=download_dir)
-        shutil.move(Path(download_dir, build_dir_name), destination)
+        shutil.move(str(Path(download_dir, build_dir_name)), destination)
 
 
 def project_file_from_template(template_dir: Path, destination_dir: Path, template_name: str, **kwargs: Any) -> None:
@@ -129,14 +144,17 @@ def print_pretty_report(
         guide_style="bold bright_blue",
     )
 
+    help_texts = {} if help_texts is None else help_texts
+
     paths = sorted(
         directory.glob("*"),
         key=lambda p: (p.is_file(), p.name.lower()),
     )
     max_witdth = max(len(p.name) for p in paths)
 
+    patterns_to_ignore = [] if ignore_patterns is None else ignore_patterns
     for path in paths:
-        if any(re.match(pattern, path.name) for pattern in ignore_patterns):
+        if any(re.match(pattern, path.name) for pattern in patterns_to_ignore):
             # Only display relevant files
             continue
 
@@ -149,6 +167,8 @@ def print_pretty_report(
         text_pathname.append(f" {padding} {help_text}", "blue")
 
         icon = "📂 " if path.is_dir() else "📄 "
+        icon = icon if _can_encode_icon(icon) else ""
+
         tree.add(Text(icon) + text_pathname)
 
     print("\n")
@@ -156,3 +176,12 @@ def print_pretty_report(
     print(tree)
     print("\nRun it:\n")
     print(Panel(f"[red]lightning run app {directory.relative_to(Path.cwd()) / 'app.py'}"))
+
+
+def _can_encode_icon(icon: str) -> bool:
+    """Helper function to check whether an icon can be encoded."""
+    try:
+        icon.encode(sys.stdout.encoding)
+        return True
+    except UnicodeEncodeError:
+        return False
