@@ -1,3 +1,17 @@
+# Copyright The Lightning AI team.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 from abc import ABC, abstractmethod
 from typing import Optional, TYPE_CHECKING
 
@@ -15,7 +29,7 @@ class Frontend(ABC):
         self.flow: Optional["LightningFlow"] = None
 
     @abstractmethod
-    def start_server(self, host: str, port: int) -> None:
+    def start_server(self, host: str, port: int, root_path: str = "") -> None:
         """Start the process that serves the UI at the given hostname and port number.
 
         Arguments:
@@ -23,13 +37,16 @@ class Frontend(ABC):
                 but defaults to localhost when running locally.
             port: The port number where the UI will be served. This gets determined by the dispatcher, which by default
                 chooses any free port when running locally.
+            root_path: root_path for the server if app in exposed via a proxy at `/<root_path>`
+
 
         Example:
+
             An custom implementation could look like this:
 
             .. code-block:: python
 
-                def start_server(self, host, port):
+                def start_server(self, host, port, root_path=""):
                     self._process = subprocess.Popen(["flask", "run" "--host", host, "--port", str(port)])
         """
 
