@@ -36,7 +36,7 @@ from rich.color import ANSI_COLOR_NAMES
 
 from lightning_app import LightningApp, LightningFlow
 from lightning_app.cli.lightning_cli import run_app
-from lightning_app.core.constants import LIGHTNING_CLOUD_PROJECT_ID
+from lightning_app.core import constants
 from lightning_app.runners.multiprocess import MultiProcessRuntime
 from lightning_app.testing.config import _Config
 from lightning_app.utilities.app_logs import _app_logs_reader
@@ -50,7 +50,6 @@ from lightning_app.utilities.packaging.lightning_utils import get_dist_path_if_e
 from lightning_app.utilities.proxies import ProxyWorkRun
 
 if _is_playwright_available():
-    import playwright
     from playwright.sync_api import HttpCredentials, sync_playwright
 
 
@@ -248,8 +247,8 @@ def run_app_in_cloud(
 ) -> Generator:
     """This utility is used to automate testing e2e application with lightning.ai."""
     # 1. Validate the provide app_folder is correct.
-    if not os.path.exists(os.path.join(app_folder, "app.py")):
-        raise Exception("The app folder should contain an app.py file.")
+    if not os.path.exists(os.path.join(app_folder, app_name)):
+        raise Exception(f"The app folder should contain an {app_name} file.")
     if app_folder.endswith("/"):
         app_folder = app_folder[:-1]
 
@@ -315,6 +314,14 @@ def run_app_in_cloud(
             process = Popen((cmd + extra_args), cwd=tmpdir, env=env_copy, stdout=stdout, stderr=sys.stderr)
             process.wait()
 
+        # Fallback URL to prevent failures in case we don't get the admin URL
+        admin_url = _Config.url
+        with open(stdout_path) as fo:
+            for line in fo.readlines():
+                if line.startswith("APP_LOGS_URL: "):
+                    admin_url = line.replace("APP_LOGS_URL: ", "")
+                    break
+
         if is_editable_mode:
             # Added to ensure the current code is properly uploaded.
             # Otherwise, it could result in un-tested PRs.
@@ -341,62 +348,6 @@ def run_app_in_cloud(
             record_video_dir=os.path.join(_Config.video_location, TEST_APP_NAME),
             record_har_path=_Config.har_location,
         )
-        admin_page = context.new_page()
-        print(f"The Lightning App Token is: {token}")
-        print(f"The Lightning App user key is: {_Config.key}")
-        print(f"The Lightning App user id is: {_Config.id}")
-        admin_page.goto(_Config.url)
-        admin_page.evaluate(
-            """data => {
-            window.localStorage.setItem('gridUserId', data[0]);
-            window.localStorage.setItem('gridUserKey', data[1]);
-            window.localStorage.setItem('gridUserToken', data[2]);
-        }
-        """,
-            [_Config.id, _Config.key, token],
-        )
-        if LIGHTNING_CLOUD_PROJECT_ID:
-            admin_page.evaluate(
-                """data => {
-                window.localStorage.setItem('gridDefaultProjectIdOverride', JSON.stringify(data[0]));
-            }
-            """,
-                [LIGHTNING_CLOUD_PROJECT_ID],
-            )
-        admin_page.goto(f"{_Config.url}/{_Config.username}/apps", timeout=60 * 1000)
-
-        # Closing the Complete your profile dialog
-        try:
-            dialog = admin_page.locator("text=Complete your profile")
-            dialog.wait_for(timeout=10 * 1000, state="visible")
-            print("'Complete your profile' dialog visible, closing it.")
-            admin_page.locator('input[name="firstName"]').fill("first")
-            admin_page.locator('input[name="lastName"]').fill("last")
-            admin_page.locator('input[name="email"]').fill("e2e.test.admin@lightning.ai")
-            admin_page.locator('input[name="organization"]').fill("Lightning AI")
-            button = admin_page.locator('button:has-text("Confirm")')
-            button.wait_for(timeout=3 * 1000)
-            button.click()
-        except playwright._impl._api_types.TimeoutError:
-            print("'Complete your profile' dialog not visible, skipping.")
-
-        # Closing the Create Project dialog.
-        try:
-            project_dialog = admin_page.locator("text=Create a project")
-            project_dialog.wait_for(timeout=10 * 1000, state="visible")
-            print("'Create Project' dialog visible, closing it.")
-            project_name_input = admin_page.locator('input[type="text"]')
-            project_name_input.fill("Default Project")
-            button = admin_page.locator('button:has-text("Continue")')
-            button.wait_for(timeout=3 * 1000)
-            button.click()
-        except playwright._impl._api_types.TimeoutError:
-            print("'Create Project' dialog not visible, skipping.")
-
-        admin_page.locator(f'[data-cy="{name}"]').click()
-
-        app_url = admin_page.url
-        admin_page.goto(app_url + "/logs")
 
         client = LightningClient()
         project_id = _get_project(client).project_id
@@ -409,6 +360,26 @@ def run_app_in_cloud(
             process = Process(target=_print_logs, kwargs={"app_id": app_id})
             process.start()
 
+        admin_page = context.new_page()
+        admin_page.goto(admin_url)
+        admin_page.evaluate(
+            """data => {
+            window.localStorage.setItem('gridUserId', data[0]);
+            window.localStorage.setItem('gridUserKey', data[1]);
+            window.localStorage.setItem('gridUserToken', data[2]);
+        }
+        """,
+            [_Config.id, _Config.key, token],
+        )
+        if constants.LIGHTNING_CLOUD_PROJECT_ID:
+            admin_page.evaluate(
+                """data => {
+                window.localStorage.setItem('gridDefaultProjectIdOverride', JSON.stringify(data[0]));
+            }
+            """,
+                [constants.LIGHTNING_CLOUD_PROJECT_ID],
+            )
+
         view_page = context.new_page()
         i = 1
         while True:
