@@ -1,3 +1,17 @@
+# Copyright The Lightning AI team.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 from random import choice, randint
 
 _adjectives = [
@@ -1332,12 +1346,13 @@ def get_unique_name():
     Original source:
         https://raw.githubusercontent.com/moby/moby/master/pkg/namesgenerator/names-generator.go
 
-    Examples
-    --------
-    >>> get_unique_name()  # doctest: +SKIP
-    'focused-turing-23'
-    >>> get_unique_name()  # doctest: +SKIP
-    'thirsty-allen-9200'
+    Examples:
+
+    >>> import random ; random.seed(42)
+    >>> get_unique_name()
+    'meek-ardinghelli-4506'
+    >>> get_unique_name()
+    'truthful-dijkstra-2286'
     """
     adjective, surname, i = choice(_adjectives), choice(_surnames), randint(0, 9999)
     return f"{adjective}-{surname}-{i}"
